@@ -1,5 +1,6 @@
 #!/usr/pkg/bin/python3.11
 """The ipcluster application."""
+
 import asyncio
 import errno
 import json
@@ -441,7 +442,7 @@ class IPClusterEngines(BaseParallelApplication):
     async def start_engines(self):
         try:
             await self.cluster.start_engines()
-        except:
+        except BaseException:
             self.log.exception("Engine start failed")
             self.exit(1)
 
